[<prev] [next>] [thread-next>] [day] [month] [year] [list]
Message-Id: <1468694486-6156-1-git-send-email-tomas.winkler@intel.com>
Date: Sat, 16 Jul 2016 21:41:26 +0300
From: Tomas Winkler <tomas.winkler@...el.com>
To: Andy Whitcroft <apw@...onical.com>, Joe Perches <joe@...ches.com>
Cc: linux-kernel@...r.kernel.org,
Tomas Winkler <tomas.winkler@...el.com>
Subject: [PATCH] checkpatch: don't complain about BIT macro in uapi
BIT macro cannot be exported to UAPI, so don't complain about it in
uapi headers.
Signed-off-by: Tomas Winkler <tomas.winkler@...el.com>
---
scripts/checkpatch.pl | 5 +++--
1 file changed, 3 insertions(+), 2 deletions(-)
diff --git a/scripts/checkpatch.pl b/scripts/checkpatch.pl
index a0e511206f24..eee57484e42f 100755
--- a/scripts/checkpatch.pl
+++ b/scripts/checkpatch.pl
@@ -5733,8 +5733,9 @@ sub process {
}
}
-# check for #defines like: 1 << <digit> that could be BIT(digit)
- if ($line =~ /#\s*define\s+\w+\s+\(?\s*1\s*([ulUL]*)\s*\<\<\s*(?:\d+|$Ident)\s*\)?/) {
+# check for #defines like: 1 << <digit> that could be BIT(digit), it is not exported to uapi
+ if ($realfile !~ m@...clude/uapi/@ &&
+ $line =~ /#\s*define\s+\w+\s+\(?\s*1\s*([ulUL]*)\s*\<\<\s*(?:\d+|$Ident)\s*\)?/) {
my $ull = "";
$ull = "_ULL" if (defined($1) && $1 =~ /ll/i);
if (CHK("BIT_MACRO",
--
2.5.5
Powered by blists - more mailing lists